@@ -11,6 +11,6 @@ class BuscaBoleto(Base):
 
     def execute(self, id_integracao):
 
-        uri = '%s1/boletos?IdIntegracao=%s' % (self.environment.api, id_integracao)
+        uri = '%sboletos?IdIntegracao=%s' % (self.environment.api, id_integracao)
 
         return self.send_request("GET", uri)
